def mergeSort(A):
    if len(A) > 1:
            # divide
            m = len(A) // 2
            right = A[m:]
            left = A[:m]
            # conquer
            mergeSort(left)
            mergeSort(right)
            # combine
            i = 0; j = 0; n = 0
            while i < len(left) and j < len(right):
                if left[i] < right[j]:
                    A[n] = left[i]
                    i += 1
                else:
                    A[n] = right[j]
                    j += 1
                n += 1
            while i < len(left):
                A[n] = left[i]
                n += 1
                i += 1
            while j < len(right):
                A[n] = right[j]
                n += 1
                j += 1
    return A


from setuptools import setup

def readme():
    with open('README.md') as f:
        README = f.read()
    return README


setup(
    name="pysortpack",
    version="0.0.4",
    description="A package to perform different types Sorting algorithms.",
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/J0schu/pysortpack",
    author="J0schu",
    license="MIT",
    keywords=["sort", "sorting"],
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ]
)